# Instructions

## Length

```
    Converting the measurement units of Length
```
1. km2m()
```
    Kilometer (km) to meter (m)
```
2. m2km()
```
    Meter (m) to kilometer (km)
```
3. hm2m()
```
    Hectometer (hm) to meter (m)
```
4. m2hm()
```
    Meter (m) to hectometer (hm)
```
5. dam2m()
```
    Dacameter (dam) to meter (m)
```
6. m2dam()
```
    Meter (m) to decameter (dam)
```
7. m2dm()
```
    Meter (m) to decimeter (dm)
```
8. dm2m()
```
    Decimeter (dm) to meter (m)
```
9. m2cm()
```
    Meter (m) to centimeter (cm)
```
10. cm2m()
```
    Centimeter (cm) to meter (m)
```
11. m2mm()
```
    Meter (m) to milimeter (mm)
```
12. mm2m()
```
    Milimeter (mm) to meter (m)
```
13. in2cm()
```
    Inch (in) to centimeter (cm)
```
14. cm2in()
```
    Centimeter (cm) to inch (in)
```

## Weight and Mass

```Converting the measurement units of Weight and Mass
```

## Temperature

```
    Converting the measurement units of Temperature
```